"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShipStatus = void 0;
const Enums_1 = require("../../constant/Enums");
const Networkable_1 = require("../Networkable");
const AutoDoorsSystem_1 = require("../systems/AutoDoorsSystem");
const HudOverrideSystem_1 = require("../systems/HudOverrideSystem");
const LifeSuppSystem_1 = require("../systems/LifeSuppSystem");
const MedScanSystem_1 = require("../systems/MedScanSystem");
const ReactorSystem_1 = require("../systems/ReactorSystem");
const SabotageSystem_1 = require("../systems/SabotageSystem");
const SecurityCameraSystem_1 = require("../systems/SecurityCameraSystem");
const SwitchSystem_1 = require("../systems/SwitchSystem");
class ShipStatus extends Networkable_1.Networkable {
    constructor(netid, data) {
        super(netid, data);
        this.classname = "ShipStatus";
    }
    Deserialize(reader, spawn = false) {
        if (!this.systems) {
            this.systems = {
                [Enums_1.SystemType.Reactor]: new ReactorSystem_1.ReactorSystem,
                [Enums_1.SystemType.Electrical]: new SwitchSystem_1.SwitchSystem,
                [Enums_1.SystemType.O2]: new LifeSuppSystem_1.LifeSuppSystem,
                [Enums_1.SystemType.MedBay]: new MedScanSystem_1.MedScanSystem,
                [Enums_1.SystemType.Security]: new SecurityCameraSystem_1.SecurityCameraSystem,
                [Enums_1.SystemType.Communications]: new HudOverrideSystem_1.HudOverrideSystem,
                [Enums_1.SystemType.Doors]: new AutoDoorsSystem_1.AutoDoorsSystem,
                [Enums_1.SystemType.Sabotage]: new SabotageSystem_1.SabotageSystem
            };
        }
        this.DeserializeStep2(reader, spawn); // Step 2 so the HeadQuarters, PolusMap and AprilShipStatus that extend from ShipStatus can put their own systems in onspawn beforehand.
    }
    DeserializeStep2(reader, spawn = false) {
        if (spawn) {
            for (let i = 0; i < 32; i++) {
                const system = this.systems[i];
                if (system) {
                    system.Deserialize(reader, spawn);
                }
            }
        }
        else {
            const mask = reader.upacked();
            for (let i = 0; i < 32; i++) {
                const system = this.systems[i];
                if (system && (mask & (1 << i))) {
                    system.Deserialize(reader, spawn);
                }
            }
        }
    }
    /* eslint-disable-next-line */
    Serialize(writer, spawn = false) {
    }
}
exports.ShipStatus = ShipStatus;
ShipStatus.classname = "ShipStatus";
