import assert from "assert"

import {
    Code2Int,
    Int2Code,
    V1Code2Int,
    V1Int2Code,
    V2Code2Int,
    V2Int2Code
} from "../ts/lib/util/Codes"

describe("V1Code2Int", () => {
    it("Should convert a version 1 game code to an integer.", () => {
        assert.strictEqual(V1Code2Int("SWAG"), 1398227271);
        assert.strictEqual(V1Code2Int("CODE"), 1129268293);
        assert.strictEqual(V1Code2Int("WEAK"), 1464156491);
        assert.strictEqual(V1Code2Int("EYES"), 1163478355);
    });
});

describe("V1Int2Code", () => {
    it("Should convert an integer to a version 1 game code.", () => {
        assert.strictEqual(V1Int2Code(1195461957), "GAME");
        assert.strictEqual(V1Int2Code(1313817669), "NODE");
        assert.strictEqual(V1Int2Code(1245795905), "JAVA");
        assert.strictEqual(V1Int2Code(1413829460), "TEST");
    });
});

describe("V2Code2Int", () => {
    it("Should convert a version 2 game code to an integer.", () => {
        assert.strictEqual(V2Code2Int("SOGOOD"), -1954553379);
        assert.strictEqual(V2Code2Int("LOVEIT"), -2060029478);
        assert.strictEqual(V2Code2Int("NUMTWO"), -1822699133);
        assert.strictEqual(V2Code2Int("PACKET"), -2069508463);
    });
});

describe("V2Int2Code", () => {
    it("Should convert an integer to a version 2 game code.", () => {
        assert.strictEqual(V2Int2Code(-2070057481), "SCRIPT");
        assert.strictEqual(V2Int2Code(-2080903964), "VECTOR");
        assert.strictEqual(V2Int2Code(-1979833231), "STATES");
        assert.strictEqual(V2Int2Code(-2068673179), "CHRIST");
    });
});

describe("Code2Int", () => {
    it("Should detect the version of a game code and convert it to an integer.", () => {
        assert.strictEqual(Code2Int("BIRD"), 1112101444);
        assert.strictEqual(Code2Int("DIGITS"), -1982135738);
        assert.strictEqual(Code2Int("FARM"), 1178686029);
        assert.strictEqual(Code2Int("RECOIL"), -2023768877);
    });
});

describe("Int2Code", () => {
    it("Should convert an integer to a game code, automatically detecting the version.", () => {
        assert.strictEqual(Int2Code(1296649285), "MILE");
        assert.strictEqual(Int2Code(-2043721391), "AGENCY");
        assert.strictEqual(Int2Code(1515146821), "ZONE");
        assert.strictEqual(Int2Code(-2022060824), "MENTAL");
    });
});